# rwsdigital-utils

<div id="top"></div>
<div align="center">
  <a href="https://github.com/sCast17/rwsdigital-utils">
    <img src="https://i0.wp.com/www.rwsdigital.com/wp-content/uploads/2018/09/logo-copyright.png?fit=708%2C177&ssl=1"" 
         alt="Logo" width="500" height="130" align="center">
  </a>

  <h3 align="center">RWSdigital Utils</h3>

  <p align="center">
    Utils to enhance software development in RWSdigital!
  </p>
</div>



<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>


## About The Project
                          

### Built With

* [Python](https://www.python.org/)


## Getting Started

Insert text here.


### Installation

1. Install via pip
   ```sh
   pip install rwsdigital-utils
   ```
2. Enjoy


## License

Distributed under the MIT License. See `LICENSE` for more information.


## Contact

Salvatore Castaldo - salvatore.cast17@gmail.com

Project Link: [https://github.com/sCast17/rwsdigital-utils](https://github.com/sCast17/rwsdigital-utils)
